@@ -22,5 +22,5 @@ from pyccuracy.page import PageRegistry, Page
 from pyccuracy.drivers import DriverRegistry
 from pyccuracy.drivers.core import *
 
-Version = "1.0.5"
-Release = "Viagra"
+Version = "1.2.0"
+Release = "Clarytin"
